Script Collection
=================
Various scripts which were useful during my PhD.

.. image:: https://readthedocs.org/projects/rad-tools/badge/?version=stable
    :target: https://rad-tools.adrybakov.com/en/stable/?badge=stable
    :alt: Documentation Status

Installation
------------

First make sure that you have python3 and pip installed.
Then execute the following in your terminal:

.. code-block:: console

   pip install rad-tools

Documentation
=============

Documentations is available 
`here. <https://rad-tools.adrybakov.com/en/latest/index.html>`_
